package com.stephengware.java.mss;

/**
 * The parent class of every kind of event that can be returned by an
 * {@link EventQueue}.
 * 
 * @author Stephen G. Ware
 * @version 1
 */
public class Event {
	
	/**
	 * The various types of events.
	 * 
	 * @author Stephen G. Ware
	 * @version 1
	 */
	public static enum Type {
		SERVER_START,
		CONNECT,
		INPUT,
		DISCONNECT,
		EXCEPTION,
		SERVER_STOP;
	}
	
	/**
	 * Define what kind of event this is.
	 */
	public final Type type;
	
	/**
	 * Creates a new event.
	 * 
	 * @param type the event type
	 */
	Event(Type type){
		this.type = type;
	}

	/**
	 * This event is always returned first by {@link EventQueue#pop()}.
	 */
	public static final Event SERVER_START_EVENT = new Event(Type.SERVER_START);
	
	/**
	 * This event is always returned last by {@link EventQueue#pop()}.
	 */
	public static final Event SERVER_STOP_EVENT = new Event(Type.SERVER_STOP);
}
